@@ -34,7 +34,7 @@ from xpresso.exceptions import HTTPException
 from xpresso.responses import ResponseSpec
 
 __all__ = (
-    "APIRouter",
+    "Router",
     "Operation",
     "Path",
     "Mount",
@@ -76,7 +76,7 @@ class _OperationApp:
         xpresso_scope: asgi_scope_extension.xpressoASGIExtension = scope["extensions"][
             "xpresso"
         ]
-        async with xpresso_scope["container"].enter_scope("endpoint") as container:
+        async with xpresso_scope["container"].enter_scope("operation") as container:
             endpoint_return = await container.execute_async(
                 self.dependant,
                 values=values,
@@ -118,6 +118,7 @@ class Operation(starlette.routing.BaseRoute):
             [typing.Any], starlette.responses.Response
         ] = starlette.responses.JSONResponse,
         response_encoder: Encoder = JsonableEncoder(),
+        sync_to_thread: bool = True,
     ) -> None:
         self._app: typing.Optional[starlette.types.ASGIApp] = None
         self.endpoint = endpoint
@@ -135,6 +136,7 @@ class Operation(starlette.routing.BaseRoute):
         self.response_encoder = response_encoder
         self.include_in_schema = include_in_schema
         self.name: str = starlette.routing.get_name(endpoint) if name is None else name  # type: ignore
+        self.sync_to_thread = sync_to_thread
 
     async def handle(
         self,
@@ -149,12 +151,11 @@ class Operation(starlette.routing.BaseRoute):
     def solve(
         self,
         container: BaseContainer,
-        path_params: typing.Set[str],
         dependencies: typing.List[DependantBase[typing.Any]],
     ) -> None:
         self.dependant = container.solve(
             JoinedDependant(
-                Dependant(self.endpoint),
+                Dependant(self.endpoint, sync_to_thread=self.sync_to_thread),
                 siblings=[*dependencies, *(self.dependencies or ())],
             )
         )
@@ -288,14 +289,14 @@ class Path(starlette.routing.Route):
 def _not_supported(method: str) -> typing.Callable[..., typing.Any]:
     def raise_error(*args: typing.Any, **kwargs: typing.Any) -> typing.NoReturn:
         raise NotImplementedError(
-            f"Use of APIRouter.{method} is deprecated."
-            " Use APIRouter(routes=[...]) instead."
+            f"Use of Router.{method} is deprecated."
+            " Use Router(routes=[...]) instead."
         )
 
     return raise_error
 
 
-class APIRouter(starlette.routing.Router):
+class Router(starlette.routing.Router):
     routes: typing.List[starlette.routing.BaseRoute]
 
     def __init__(
